@@ -1,4 +1,4 @@
-module Happstack.Auth 
+module Happstack.Auth
     ( UserId(..)
     , AuthState(..)
     , ProfileState(..)
@@ -10,6 +10,7 @@ module Happstack.Auth
     , handleAuth
     , handleProfile
     , handleAuthProfile
+    , handleAuthProfileRouteT
     ) where
 
 import Happstack.Auth.Core.Profile    (UserId(..), getUserId)
@@ -18,4 +19,4 @@ import Happstack.Auth.Core.AuthURL    (AuthURL(..))
 import Happstack.Auth.Core.Profile    (ProfileState(..))
 import Happstack.Auth.Core.ProfileURL (ProfileURL(..))
 import Happstack.Auth.Core.AuthProfileURL (AuthProfileURL(..))
-import Happstack.Auth.Blaze.Templates (authProfileHandler, handleAuth, handleProfile, handleAuthProfile)
\ No newline at end of file
+import Happstack.Auth.Blaze.Templates (authProfileHandler, handleAuth, handleProfile, handleAuthProfile, handleAuthProfileRouteT)
\ No newline at end of file
